Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(985)

Unified Diff: chrome/browser/ui/omnibox/omnibox_edit_controller.h

Issue 11418043: Remove TabContents from OmniboxEditController and friends. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: cros Created 8 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/ui/gtk/location_bar_view_gtk.cc ('k') | chrome/browser/ui/omnibox/omnibox_edit_model.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/ui/omnibox/omnibox_edit_controller.h
diff --git a/chrome/browser/ui/omnibox/omnibox_edit_controller.h b/chrome/browser/ui/omnibox/omnibox_edit_controller.h
index f6dac47a55ed78aecb7f9f6f5521b89c38bef45d..491ef7d95e486794f1f893b60f21c96335317e62 100644
--- a/chrome/browser/ui/omnibox/omnibox_edit_controller.h
+++ b/chrome/browser/ui/omnibox/omnibox_edit_controller.h
@@ -11,7 +11,10 @@
class GURL;
class InstantController;
-class TabContents;
+
+namespace content {
+class WebContents;
+}
namespace gfx {
class Image;
@@ -63,8 +66,8 @@ class OmniboxEditController {
// Returns the InstantController, or NULL if instant is not enabled.
virtual InstantController* GetInstant() = 0;
- // Returns the TabContents of the currently active tab.
- virtual TabContents* GetTabContents() const = 0;
+ // Returns the WebContents of the currently active tab.
+ virtual content::WebContents* GetWebContents() const = 0;
protected:
virtual ~OmniboxEditController() {}
« no previous file with comments | « chrome/browser/ui/gtk/location_bar_view_gtk.cc ('k') | chrome/browser/ui/omnibox/omnibox_edit_model.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698